import logging
import formencode
import formencode.htmlfill

from pylons import config, request
from pylons.controllers.util import redirect

from repoze.what.plugins.pylonshq import ControllerProtector

from webhelpers.paginate import Page

from sloecode.lib.base import BaseController
from sloecode.model.project import Project, ProjectSchema
from sloecode.model.person import Person
from sloecode.model.membership import Membership
from sloecode.model.site_role import PROJECT_ADMIN
from sloecode.model.meta import Session
from sloecode.lib.predicates import has_site_role
import sloecode.lib.helpers as h

log = logging.getLogger(__name__)

@ControllerProtector(has_site_role(PROJECT_ADMIN))
class ProjectController(BaseController):
    """ProjectController contains basic admin functionality for the Project
    model.

    This includes basic CRUD information.
    """

    def index(self, project_name):
        projects = Project.get(name=project_name)
        existing_project = projects[0] if projects else None
        return self.render('/project-details.html', {'project': existing_project, 'project_name': project_name})
    
    def manage_users(self, project_name):
        """
        Add/Remove users from this project.
        """
        all_people = Person.get()
        return self.render('/project-manage-users.html', {'all_people':all_people, 'project_name': project_name})
    
    def process_manage_users(self, project_name):
        """
        Process the change in the users-in-projects
        """
        selected_people = request.params.getall('usernames')

        for user in selected_people:
            user_details = Person.get(login = user)
            new_membership = Membership()
            new_membership.person_id = user_details[0].id
            new_membership.project_id = 1
            
            Session.add(new_membership)
            Session.commit()

            h.flash("Added %s Successfully" % user_details[0].name)

        return redirect('/p/%s' % project_name)
